pub fn make_mut<T: Clone>(this: &mut OwnShared<T>) -> &mut TExpand description
Get a mutable reference to the underlying data, with semantics similar to Arc::make_mut().
pub fn make_mut<T: Clone>(this: &mut OwnShared<T>) -> &mut TGet a mutable reference to the underlying data, with semantics similar to Arc::make_mut().